@@ -279,7 +279,11 @@ class _UnsignedGetter:
                 if resp.status != 200:
                     raise FlureeHttpError(await resp.text(), resp.status)
                 response = await resp.text()
-                return json.loads(response)
+                try:
+                    rval = json.loads(response)
+                except json.decoder.JSONDecodeError:
+                    rval = response
+                return rval
 
     async def ready(self):
         """Redo get untill ready condition gets met"""
@@ -589,9 +593,10 @@ class FlureeClient:
                                     "health",
                                     "new_keys",
                                     "sub",
-                                    "nw_state"])
-        self.unsigned_endpoints = set(["dbs", "health", "new_keys"])
-        self.use_get = set(["health", "new_keys"])
+                                    "nw_state",
+                                    "version"])
+        self.unsigned_endpoints = set(["dbs", "health", "new_keys", "nw_state", "version"])
+        self.use_get = set(["health", "new_keys", "nw_state", "version"])
         self.required = {}
         self.required["new_db"] = set(["db_id"])
         self.required["delete_db"] = set(["db_id"])
@@ -604,7 +609,9 @@ class FlureeClient:
                                 "new_db",
                                 "delete_db",
                                 "add_server",
-                                "remove_server"])
+                                "remove_server",
+                                "nw_state",
+                                "version"])
 
     async def __aenter__(self):
         """Method for allowing 'with' constructs
@@ -834,6 +841,8 @@ class _FlureeDbClient:
         self.pw_endpoints = set(["generate", "renew", "login"])
         self.implemented = set(["query",
                                 "flureeql",
+                                "sql",
+                                "sparql",
                                 "block",
                                 "command",
                                 "ledger_stats",
@@ -1624,13 +1633,15 @@ class _FlureeDbClient:
                             raise FlureeHttpError(await resp.text(), resp.status)
                         return await resp.text()
 
-            async def header_signed(self, query_body):
+            async def header_signed(self, query_body, contenttype="application/json"):
                 """Do a HTTP query using headers for signing
 
                 Parameters
                 ----------
                 query_body : any
                        query body to sign using headers.
+                contenttype : string
+                       Content-type of query, defaults to application/json
 
                 Returns
                 -------
@@ -1641,7 +1652,7 @@ class _FlureeDbClient:
                     body, headers, _ = self.signer.sign_query(query_body, querytype=self.api_endpoint)
                 else:
                     body = json.dumps(query_body, indent=4, sort_keys=True)
-                    headers = {"Content-Type": "application/json"}
+                    headers = {"Content-Type": contenttype}
                 return await self._post_body_with_headers(body, headers)
 
             async def body_signed(self, transact_obj, deps=None):
@@ -1899,6 +1910,38 @@ class _FlureeDbClient:
                 return_body = await self.stringendpoint.empty_post_unsigned()
                 return json.loads(return_body)
 
+        class StringQueryEndpoint:
+            """Endpoint for low level string querying (sql/sparql endpoints)"""
+            def __init__(self, endpoint, client, ssl_verify_disabled=False):
+                """Constructor
+
+                Parameters
+                ----------
+                endpoint: string
+                        Name of the endpoint
+                client: object
+                        The wrapping _FlureeDbClient
+                ssl_verify_disabled: bool
+                        When using https, don't validata ssl certs.
+                """
+                self.stringendpoint = _StringEndpoint(endpoint, client, ssl_verify_disabled)
+
+            async def __call__(self, query_string):
+                """Send request to ledger-stats endpoint and retrieve result
+
+                Parameters
+                ----------
+                query : string
+                        Query in the proper query language (sql or sparql depending on endpoint name)
+
+                Returns
+                -------
+                dict
+                    json decode result from the server.
+                """
+                return_body = await self.stringendpoint.header_signed(query_string, contenttype="text/plain")
+                return json.loads(return_body)
+
         if api_endpoint not in self.known_endpoints:
             raise AttributeError("FlureeDB has no endpoint named " + api_endpoint)
         if api_endpoint not in self.implemented:
@@ -1911,4 +1954,6 @@ class _FlureeDbClient:
             return FlureeQlEndpointMulti(self, self.ssl_verify_disabled)
         if api_endpoint == 'ledger_stats':
             return LedgerStatsEndpoint(self, self.ssl_verify_disabled)
+        if api_endpoint in ["sql", "sparql"]:
+            return StringQueryEndpoint(api_endpoint, self, self.ssl_verify_disabled)
         return FlureeQlEndpoint(api_endpoint, self, self.ssl_verify_disabled)
